/*
 * This file is part of libdom.
 * Licensed under the MIT License,
 *                http://www.opensource.org/licenses/mit-license.php
 * Copyright 2007 John-Mark Bell <jmb@netsurf-browser.org>
 */

#ifndef dom_core_entityreference_h_
#define dom_core_entityreference_h_

typedef struct dom_entity_reference dom_entity_reference;

#endif
